@@ -14,8 +14,6 @@ Rapid is recommended for most work.
 See documentation at: https://docs.rowansci.com/science/workflows/bond-dissociation-energy
 """
 
-import json
-
 from stjames import Molecule
 
 import rowan
@@ -23,12 +21,17 @@ import rowan
 # rowan.api_key = ""
 
 # Run calculation remotely
-result = rowan.compute(
-    Molecule.from_smiles("CCCC"),
+result = rowan.submit_workflow(
+    initial_molecule=Molecule.from_smiles("CCCC"),
     workflow_type="bde",
     name="Butane BDE",
-    mode="reckless",
-    all_CH=True,
+    workflow_data={
+        "mode": "reckless",
+        "all_CH": "true",
+    },
 )
 
-print(json.dumps(result, indent=4))
+result.wait_for_result()
+result.fetch_latest(in_place=True)
+
+print(result)
