@@ -10,4 +10,4 @@ result = rowan.submit_macropka_workflow(
 )
 
 
-print(result)
+print(result.wait_for_result().fetch_latest(in_place=True))
